| Title: | Interactive Table with LaTeX And OGC Layers |
|---|---|
| Description: | Who said PDF can't be interactive? This package allows to create some interactive tables with LaTeX using PDF Layers/Optional Content Groups (OCG). |
| Authors: | Alain Quartier-la-Tente [aut, cre] (ORCID: <https://orcid.org/0000-0001-7890-3857>) |
| Maintainer: | Alain Quartier-la-Tente <[email protected]> |
| License: | What license is it under? |
| Version: | 0.1.0 |
| Built: | 2026-05-08 05:09:52 UTC |
| Source: | https://github.com/AQLT/Rogctable |
Sortable Table
ogc_hide(x, align, show = 1, label = NULL, vline = "", striped = FALSE)ogc_hide(x, align, show = 1, label = NULL, vline = "", striped = FALSE)
show |
the layer to show by default. The first layer contains all the date, the second layer hide the second column, etc. |
Create OGC table with 'Tiks'
ogc_table(x, align, label = NULL, vline = "", striped = FALSE)ogc_table(x, align, label = NULL, vline = "", striped = FALSE)
x |
a |
align, label, vline
|
see knitr::kable. |
striped |
boolean |